oe_download_directory: Return the download directory used by the package

View source: R/utils.R

oe_download_directoryR Documentation

Return the download directory used by the package

Description

By default, the download directory is equal to tools::R_user_dir("osmextract", "data"). You can set a different persistent or temporary download directory by adding the following command to your .Renviron file (e.g. with edit_r_environ function in usethis package): ⁠OSMEXT_DOWNLOAD_DIRECTORY=/path/where/to/save/osm/data⁠.

Usage

oe_download_directory()

Value

A character vector representing the path for the download directory used by the package.

Examples

oe_download_directory()

osmextract documentation built on April 14, 2026, 9:06 a.m.