| oe_download_directory | R Documentation |
By default, the download directory is equal to tools::R_user_dir("osmextract", "data").
You can set a different persistent or temporary download directory by adding
the following command to your .Renviron file (e.g. with edit_r_environ
function in usethis package): OSMEXT_DOWNLOAD_DIRECTORY=/path/where/to/save/osm/data.
oe_download_directory()
A character vector representing the path for the download directory used by the package.
oe_download_directory()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.