The matching between the existing files (saved in a directory
specified by download_directory parameter) and the input place is
performed using list.files, setting a pattern equal to the basename of
the URL associated to the input place. For example, if you specify
place = "Isle of Wight", then the input place is matched with a URL of
a .osm.pbf file (via oe_match()) and the matching is performed setting a
pattern equal to the basename of that URL.
If there is no file in download_directory that can be matched with the
basename and download_if_missing parameter is equal to TRUE, then the
function tries to download and translate a new file from the chosen
provider (geofabrik is the default provider). If download_if_missing
parameter is equal to FALSE (default value), then the function stops with
an error.