This function is used to display a short summary of the major characteristics of the databases associated to all available providers.
Value
A data.frame with 4 columns representing the name of each available
provider, the name of the corresponding database and the number of features
and fields.